Test Prompting Verifification

Test verify Prompting
open | ../tests/html/test_prompt.html |
verifyPromptNotPresent |  |
assertPromptNotPresent |  |
answerOnNextPrompt | no |
click | promptAndLeave |
verifyPromptPresent |  |
waitForPromptPresent |  |
assertPromptPresent |  |
verifyPrompt | Type 'yes' and click OK |
verifyTitle | Test Prompt |
answerOnNextPrompt | yes |
clickAndWait | promptAndLeave |
verifyPrompt | *'yes'* |
verifyTitle | Dummy Page |